@@ -4,8 +4,8 @@
 
 ;; Author: Hrishikesh S <hrish2006@gmail.com>
 ;; Maintainer: Hrishikesh S <hrish2006@gmail.com>
-;; Package-Version: 20260225.413
-;; Package-Revision: 56cec058a0e3
+;; Package-Version: 20260226.710
+;; Package-Revision: be19e7edfd6c
 ;; Package-Requires: ((emacs "28.1") (vterm "0.0.2") (transient "0.4.0"))
 ;; Keywords: tools, processes, convenience
 ;; URL: https://github.com/hrishikeshs/magnus
@@ -66,7 +66,6 @@
 (declare-function magnus-attention-setup-hooks "magnus-attention")
 (declare-function magnus-process-create-headless "magnus-process")
 (declare-function magnus-health-start "magnus-health")
-(declare-function magnus-chat "magnus-chat")
 (declare-function magnus-coord-setup-attention-tracking "magnus-coord")
 (declare-function magnus-coord-attention-load "magnus-coord")
 (declare-function magnus-coord-stop-reminders "magnus-coord")
@@ -476,7 +475,6 @@ lowercase keywords, nothing else.\n\nMemory:\n%s" memory))
     (require 'magnus-coord)
     (require 'magnus-attention)
     (require 'magnus-health)
-    (require 'magnus-chat)
     (magnus--migrate-data-files)
     (magnus-persistence-load)
     (magnus--agents-index-load)
